==> HCR_01F_L_64.10.0.30.zip: resources/www/app_sw_config.js <==
(function(exports) {
    exports.heat_lines_count = 1
    exports.index_multiply = 0x100
    exports.device_name = "RMO"
    exports.is_show_lines_mode = false

    exports.add_configuration = function()
    {
        let index_multiply = {
            "type": "index multiply", 
            "count": exports.heat_lines_count, 
            "multiply_coefficient": exports.index_multiply,
            "templates":[
                {"index": "B001_2","template": "change_value", "commands": templates_commands.line_mode_status()},
                {"index": "B001_1","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_2","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_3","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_4","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_5","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_6","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_7","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_8","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_9","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_10","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B003_2","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B003_3","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B003_4","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B003_5","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_2","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_3","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_4","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_5","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_6","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_7","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B007_2","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B007_3","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B007_4","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B008_2","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B008_3","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B020_1", "template": "combobox", "commands": templates_commands.line_command(), "add_class": "without_undetermined"},
                {"index": "B021_3","template": "control_mode", "commands": templates_commands.line_mode_rmo()},
                {"index": "B021_4","template": "combobox", "commands": templates_commands.emergency_mode()},
                {"index": "B021_7","template": "combobox", "commands": templates_commands.temperature_mode_rmo()},
                {"index": "B02B_3","template": "combobox", "commands": templates_commands.sensors_number_rmo()},
                {"index": "B02B_4","template": "combobox", "commands": templates_commands.sensors_number()},
                {"index": "B02B_10","template": "combobox", "commands": templates_commands.sensors_number()},
                {"index": "B028_1","template": "combobox", "commands": templates_commands.temp_trip_mode_RMO()},
                {"index": "B028_2","template": "combobox", "commands": templates_commands.temp_trip_mode_RMO()},
                {"index": "B028_3","template": "combobox", "commands": templates_commands.temp_trip_mode_RMO()},
                {"index": "B029_1","template": "combobox", "commands": templates_commands.current_trip_mode()},
                {"index": "B029_2","template": "combobox", "commands": templates_commands.current_trip_mode()},
                {"index": "B021_6","template": "percent"},
                {"index": "B021_13","template": "percent"},
                {"index": "B021_15","template": "percent"},
                {"index": "B02A_2","template": "percent"},
                {"index": "B02A_4","template": "percent"},
                {"index": "B02A_6","template": "percent"},
                {"index": "3F39_1","template": "combobox", "commands": templates_commands.sensor_type_RMO()},
                {"index": "3F39_2","template": "combobox", "commands": templates_commands.sensor_type_RMO()},
        ]}
        let subindex_multiply = {
            "type": "subindex multiply",
            "count": exports.heat_lines_count, 
            "templates":[
                {"index": "3F0F", "template": "change_value", "commands": templates_commands.do_channel_status()},
                {"index": "3F26", "template":  "combobox", "commands":templates_commands.heater_output_mode_rmo()},
        ]}
        configuration.add_multiply_templates(index_multiply)
        configuration.add_multiply_templates(subindex_multiply)
    }

    exports.hide_fields_indexes = [
        {index: 0xB02A, sub: 3},
        {index: 0xB02A, sub: 4},
        {index: 0xB02A, sub: 5},
        {index: 0xB02A, sub: 6},
        {index: 0x3F34, sub: 3},
        {index: 0x3F34, sub: 4},
        {index: 0x3F27, sub: "all"},
        {index: 0xB010, sub: 3},
        {index: 0xB020, sub: 2},
        {index: 0xB021, sub: 1},
        {index: 0xB002, sub: 6},
        {index: 0xB002, sub: 7},
        {index: 0xB002, sub: 8},
        {index: 0xB007, sub: 3},
        {index: 0xB028, sub: 2},
        {index: 0xB028, sub: 3},
        {index: 0xB02B, sub: 4},
        {index: 0xB006, sub: 3},
        {index: 0xB006, sub: 4},
        {index: 0xB006, sub: 5},
        {index: 0xB002, sub: 11},
        {index: 0xB022, sub: 5},
        {index: 0xB022, sub: 6},
    ]
})(this.app_sw_config = {})

==> HCR_01F_L_64.10.0.35.zip: resources/www/app_sw_config.js <==
(function(exports) {
    exports.heat_lines_count = 1
    exports.index_multiply = 0x100
    exports.device_name = "RMO"
    exports.is_show_lines_mode = false

    exports.add_configuration = function()
    {
        let index_multiply = {
            "type": "index multiply", 
            "count": exports.heat_lines_count, 
            "multiply_coefficient": exports.index_multiply,
            "templates":[
                {"index": "B001_2","template": "change_value", "commands": templates_commands.line_mode_status()},
                {"index": "B001_1","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_2","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_3","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_4","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_5","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_6","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_7","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_8","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_9","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B002_10","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B003_2","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B003_3","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B003_4","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B003_5","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_2","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_3","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_4","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_5","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_6","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B006_7","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B007_2","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B007_3","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B007_4","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B008_2","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B008_3","template": "change_value", "commands": templates_commands.alarm_trip_present()},
                {"index": "B020_1", "template": "combobox", "commands": templates_commands.line_command(), "add_class": "without_undetermined"},
                {"index": "B021_3","template": "control_mode", "commands": templates_commands.line_mode_rmo()},
                {"index": "B021_4","template": "combobox", "commands": templates_commands.emergency_mode()},
                {"index": "B021_7","template": "combobox", "commands": templates_commands.temperature_mode_rmo()},
                {"index": "B02B_3","template": "combobox", "commands": templates_commands.sensors_number_rmo()},
                {"index": "B02B_4","template": "combobox", "commands": templates_commands.sensors_number()},
                {"index": "B02B_10","template": "combobox", "commands": templates_commands.sensors_number()},
                {"index": "B028_1","template": "combobox", "commands": templates_commands.temp_trip_mode_RMO()},
                //{"index": "B028_2","template": "combobox", "commands": templates_commands.temp_trip_mode_RMO()},
                {"index": "B028_3","template": "combobox", "commands": templates_commands.temp_trip_mode_RMO_limiter()},
                {"index": "B029_1","template": "combobox", "commands": templates_commands.current_trip_mode()},
                {"index": "B029_2","template": "combobox", "commands": templates_commands.current_trip_mode()},
                {"index": "B021_6","template": "percent"},
                {"index": "B021_13","template": "percent"},
                {"index": "B021_15","template": "percent"},
                {"index": "B02A_2","template": "percent"},
                {"index": "B02A_4","template": "percent"},
                {"index": "B02A_6","template": "percent"},
                {"index": "3F39_1","template": "combobox", "commands": templates_commands.sensor_type_RMO()},
                {"index": "3F39_2","template": "combobox", "commands": templates_commands.sensor_type_RMO()},
        ]}
        let subindex_multiply = {
            "type": "subindex multiply",
            "count": exports.heat_lines_count, 
            "templates":[
                {"index": "3F0F", "template": "change_value", "commands": templates_commands.do_channel_status()},
                {"index": "3F26", "template":  "combobox", "commands":templates_commands.heater_output_mode_rmo()},
        ]}
        configuration.add_multiply_templates(index_multiply)
        configuration.add_multiply_templates(subindex_multiply)
    }

    exports.hide_fields_indexes = [
        {index: 0xB02A, sub: 3},
        {index: 0xB02A, sub: 4},
        {index: 0xB02A, sub: 5},
        {index: 0xB02A, sub: 6},
        {index: 0x3F34, sub: 3},
        {index: 0x3F34, sub: 4},
        {index: 0x3F27, sub: "all"},
        {index: 0xB010, sub: 3},
        {index: 0xB020, sub: 2},
        {index: 0xB021, sub: 1},
        {index: 0xB002, sub: 6},
        {index: 0xB002, sub: 7},
        {index: 0xB002, sub: 8},
        {index: 0xB007, sub: 3},
        {index: 0xB028, sub: 2},
        //{index: 0xB028, sub: 3},
        {index: 0xB02B, sub: 4},
        {index: 0xB006, sub: 3},
        {index: 0xB006, sub: 4},
        {index: 0xB006, sub: 5},
        {index: 0xB002, sub: 11},
        {index: 0xB022, sub: 5},
        {index: 0xB022, sub: 6},
    ]
})(this.app_sw_config = {})
